<?php
/*
 * This file is part of Robot-in for ECCUBE3 Plugin
 *
 * Copyright (C) 2015 Hunglead,Inc. doishun All Rights Reserved.
 *
 * http://www.hunglead.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

namespace Plugin\HungleadRobotIn\Config;

use Plugin\HungleadRobotIn\Utils\DateUtil;
use Plugin\HungleadRobotIn\Utils\SimpleDateTime;



// ECCUBE3は定数が廃止されている TODO いい感じに直さないといけない
define("HUNGLEAD_PLUGIN_DIR", realpath(dirname(__FILE__)."/../")."/");
define("HUNGLEAD_PLUGIN_FILE_DOWNLOADED_DIR", HUNGLEAD_PLUGIN_DIR. "fileDownloaded/");
define("MULTISTORE_DIR", ROOT_URLPATH. ADMIN_DIR . "multistore/");
define("MULTISTORE_MAIN_NO", "multistore");
define("MULTISTORE_MAIN_TITLE", "モール連動");
define("MULTISTORE_HOME_TITLE", "ホーム");
define("MULTISTORE_ORDER_TITLE", "受注管理");
define("MULTISTORE_PRICE_TITLE", "価格管理");
define("MULTISTORE_CRAWL_TITLE", "クロール管理");
define("MULTISTORE_STOCK_TITLE", "在庫管理");
define("MULTISTORE_WATCHER_TITLE","価格監視");
define("MULTISTORE_PRODUCT_TITLE", "マスター管理");
define("MULTISTORE_SETPRODUCT_TITLE", "セット商品管理");
define("MULTISTORE_Guard_TITLE", "監視対象商品");
define("MULTISTORE_FBA_TITLE", "FBA連携管理");
define("MULTISTORE_SETTING_TITLE", "設定");
define("MULTISTORE_RANK_TITLE", "ランキング");
define("MULTISTORE_RANKINDEX_TITLE", "ランキング情報検索");
define("MULTISTORE_DETAIL_TITLE", "詳細設定");
define("ADMIN_LOG_PAGE_PASS", ROOT_URLPATH . ADMIN_DIR. "system/log.php?log=ADMIN&line_max=50");


/**
 * 定数用クラス
 * 
 * @author hunglead.doishun
 */
class HungleadConstants {

    /**
     * 店舗タイプ
     * @var array
     */
    public static $shopTypeMap = array(
        "1" => "楽天市場",
        "117" => "Yahoo!ショッピング",
        "3" => "DeNAショッピング",
        "116" => "Amazon",
        "119" => "AmazonFBA",
        "200" => "EC-CUBE",
        "103" => "Eストアショップサーブ",
        "120" => "ポンパレモール",
        "100000" => "その他",
    );

    /**
     * 店舗タイプ画像
     * @var array
     */
    public static $shopTypeImageMap = array(
        "1" => "admin/multistore/images/icn_rakuten.png",
        "117" => "admin/multistore/images/icn_yahoo.png",
        "3" => "admin/multistore/images/icn_bidders.png",
        "116" => "admin/multistore/images/icn_amazon.png",
        "119" => "admin/multistore/images/icn_amazon.png",
        "200" => "admin/multistore/images/icn_eccube.png",
        "103" => "admin/multistore/images/icn_estore.png",
        "120" => "admin/multistore/images/icn_ponpare.png",
        "100000" => "admin/multistore/images/icn_cart.png",
    );

    /**
     * ランキング画像
     * @var array
     */
    public static $rankingTypeImageMap = array(
            "-1" => "admin/multistore/images/icn_ranking_blue.png",
            "0" => "admin/multistore/images/icn_ranking_green.png",
            "1" => "admin/multistore/images/icn_ranking_red.png",
    );

    /**
     * 受注ステータス
     * @var array
     */
    public static $orderStatusMap = array(
        "1" => "新規受付",
        "3" => "発送前入金待ち",
        "4" => "発送待ち",
        "5" => "発送後入金待ち",
        "2" => "発送済み",
        "-1" => "キャンセル",
        "-2" => "保留",
        "-3" => "出荷不可"
    );

    /**
     * 受注メール種別
     */
    public static $orderMailType = array(
        "1" => "受注承諾メール",
        "2" => "入金確認メール",
        "3" => "発送メール",
        "4" => "お詫びメール",
        "5" => "キャンセルメール",
        "99" => "その他メール"
    );
    
    /**
     * 受注メール種別の表示色
     */
    public static $orderMailTypeColor = array(
        "1" => "#339966",
        "2" => "#003399",
        "3" => "#cc0000",
        "4" => "#00cc00",
        "5" => "#0000cc",
        "99" => "#660066"
    );

    /**
     * 在庫編集タイプ
     * @var array
     */
    public static $stockEditTypes = array(
        "add" => "加算",
        "sub" => "減算",
        "set" => "実数"
    );

    /**
     * 在庫CSVヘッダー
     * @var array
     */
    public static $stockCSVHeaders = array(
        "商品コード",
        "規格コード",
        "商品名",
        "項目1",
        "項目2",
        "変更種別",
        "在庫数"
    );

    /**
     * 価格監視対象商品CSVヘッダー
     * @var array
     */
    public static $priceControlCSVHeaders = array(
            "JANコード",
            "カテゴリ",
            "商品名",
            "定価",
    );

    /**
     * 有効フラグ
     * @var array
     */
    public static $activeFlags = array(
        "0" => "無効",
        "1" => "有効",
    );

    /**
     * 受注CSVヘッダー
     * @var array
     */
    public static $orderCSVHeaders = array(
        "受注ID",
        "店舗ID",
        "受注日時",
        "受注番号",
        "対応状況",
        "店舗ステータス",
        "支払方法",
        "入金日",
        "注文者氏名",
        "注文者氏名（カナ）",
        "注文者郵便番号",
        "注文者住所",
        "注文者電話番号",
        "注文者メールアドレス",
        "消費税",
        "送料",
        "手数料",
        "包装料",
        "割引金額",
        "利用ポイント",
        "請求金額",
        "メモ",
    );

    /**
     * 規格フラグ
     * @var array
     */
    public static $skuFlags = array(
        "0" => "規格なし",
        "1" => "規格あり",
    );

    /**
     * サイト別商品オプション情報パラメータ
     * @var array
     */
    public static $optionalParamMap = array(

        // 楽天
        "1" => array(
            "productUrl",
        ),
        // Yahoo
        "117" => array(
        ),
        // Bidders
        "3" => array(
            "exhibitType",
        ),
        // Amazon
        "116" => array(
        ),
        // AmazonFBA
        "119" => array(
        ),
        // ポンパレモール
        "120" => array(
            "productUrl",
        ),
        // ECCUBE
        "200" => array(
        ),
        // Eストア
        "103" => array(
        ),
        // その他
        "100000" => array(
        ),
    );

    /**
     * 送り状ソフト対応
     * @var array
     */
    public static $invoiceTypeMap = array(
        "1001" => "e飛伝II（佐川急便）",
        "1002" => "B2（ヤマト便）"
    );

    /**
     * 受注取り込み間隔
     * @var array
     */
    public static $orderIntervals = array(
        "60" => "1時間",
        "120" => "2時間",
        "180" => "3時間",
        "360" => "6時間",
        "1440" => "1日",
    );

    /**
     * 顧客マスタの統計データに対応する画像
     * @var array
     */
    public static $shopperMasterIconMap = array(
        "ShopperMLevel_10" => "admin/multistore/images/shoppermaster_10.png",
        "ShopperMLevel_1" => "admin/multistore/images/shoppermaster_1.png",
    );

    /**
     * クロールタイプIDに対応する表示名配列
     * @var array
     */
    public static $crawlTypeMap = array(

        "1" => "楽天市場",
        "2" => "Yahoo!ショッピング",
        "3" => "DeNAショッピング",
        "116" => "Amazon",
        "500" => "価格.com",
    );

    /**
     * クロールタイプIDに対応する画像
     * @var array
     */
    public static $crawlTypeImageMap = array(
        "1" => "admin/multistore/images/icn_rakuten.png",
        "2" => "admin/multistore/images/icn_yahoo.png",
        "3" => "admin/multistore/images/icn_bidders.png",
        "116" => "admin/multistore/images/icn_amazon.png",
        "500" => "admin/multistore/images/icn_kakaku.png",
    );

    public static $AutoBidInfo = array("type" => "118", "name" => "AUTOBID");
    public static $UnconfirmedProperty = array("key" => "confirm", "value" =>"unconfirmed");
}
