<?php
/*
 * This file is part of Robot-in for ECCUBE3 Plugin
 *
 * Copyright (C) 2015 Hunglead,Inc. doishun All Rights Reserved.
 *
 * http://www.hunglead.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

namespace Plugin\HungleadRobotIn\Controller;

use Eccube\Application;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Security\Core\SecurityContext;

use Plugin\HungleadRobotIn\Config\HungleadConstants;
use Plugin\HungleadRobotIn\Dao\OrderDao;
use Plugin\HungleadRobotIn\ServiceProvider\HarcServiceProvider;


/**
 * get_ordersAPIのコントローラ
 *
 * @author hunglead.doishun
 */
class GetOrdersController
{

    public function index(Application $app, Request $request)
    {
        $id         = $request->get('id', array());
        $status     = $request->get('status');
        $fromDate   = $request->get('fromDate');
        $toDate     = $request->get('toDate');

        try {
            // POSTアクセスに制限
            if($request->getMethod() != 'POST') throw new \Exception("Invalid Account.");

            $dao = new OrderDao($app);
            $orders = $dao->getOrderInfos($id, $status, $fromDate, $toDate);

            $results = array(
                  "status" => "success"
                , "orders" => $orders
            );

        } catch (\Exception $e) {
            $results = array(
                  "status" => "failed"
                , "message" => $e->getMessage()
            );
        }

        return HarcServiceProvider::sendResponse($results, 'get_orders');
    }


    public function test(Application $app, Request $request)
    {
        return $app->render('HungleadRobotIn/Resource/template/default/test/get_orders.twig', array(
        ));

    }

}
