<?php
/*
 * This file is part of Robot-in for ECCUBE3 Plugin
 *
 * Copyright (C) 2015 Hunglead,Inc. doishun All Rights Reserved.
 *
 * http://www.hunglead.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

namespace Plugin\HungleadRobotIn\Dao;

use Eccube\Application;
use Doctrine\ORM\NoResultException as NoResultException;
use Doctrine\ORM\NonUniqueResultException as NonUniqueResultException;
use Monolog\Handler\FingersCrossed\ErrorLevelActivationStrategy;
use Monolog\Handler\FingersCrossedHandler;
use Monolog\Handler\RotatingFileHandler;
use Monolog\Logger;


/**
 * Daoクラスのアブストラクトクラス
 *  # 共通処理を定義
 *
 * @author hunglead.doishun
 */
abstract class AbstractDao
{

    /**
     * @var Eccube\Application
     */
    protected $app;

    /**
     * @var Monolog\Logger
     */
    protected $Logger;

    public function __construct(Application $app)
    {
        $this->app = $app;
        $this->initLogger();
    }


    /**
     * アカウント情報を検証
     * 
     * @author doishun
     * @throws Exception
     * @param  array $id アカウント情報
     * @return void
     */
    protected function checkId($id) {
        $account  = $id["account"];
        $password = $id["password"];

        try{
            if (!$account || !$password) {
                throw new \Exception("Invalid Account.");
            }

            // login_idの妥当性チェック
            $qb = $this->app['orm.em']->createQueryBuilder();
            $qb->select("m")
               ->from("Eccube\\Entity\\Member", "m")
               ->where("m.login_id = :login_id")
               ->setParameter("login_id", $account)
               ->setMaxResults(1);

            $query = $qb->getQuery();
            $member = $query->getSingleResult();

            // パスワードの妥当性チェック
            // PasswordEncoder.encodePassword
            if(!($this->app['eccube.password_encoder']->encodePassword($password, $member->getSalt()) == $member->getPassword())){
                throw new \Exception("Invalid Account.");
            }


        // クエリの結果が0件の場合
        } catch (NoResultException $e) {
            throw new \Exception("Invalid Account.");

        } catch (NonUniqueResultException $e) {
            throw new \Exception("Invalid Account.");

        } catch (\Exception $e){
            throw $e;
        }
    }


    /**
     * ロギングクラスを設定する
     * 
     * @author doishun
     * @param  void
     * @return void
     */
    public function initLogger()
    {
        $dir  = realpath(__DIR__."/../logs/")."/";
        $file = $dir."robot-in.api.log";
//        chmod($dir, "0777");

        $RotateHandler = new RotatingFileHandler($file, $this->app['config']['log']['max_files'], $this->app['config']['log']['log_level']);
        $RotateHandler->setFilenameFormat(
            "robot-in.api." . '{date}' . $this->app['config']['log']['suffix'],
            $this->app['config']['log']['format']
        );

        $FingerCrossedHandler = new FingersCrossedHandler(
            $RotateHandler,
            new ErrorLevelActivationStrategy($levels[$this->app['config']['log']['action_level']])
        );

        $monolog = new Logger("Robot-in");
        $monolog->pushHandler($FingerCrossedHandler);
        $this->Logger = $monolog;
    }

}


?>
