<?php
/*
 * This file is part of Robot-in for ECCUBE3 Plugin
 *
 * Copyright (C) 2015 Hunglead,Inc. doishun All Rights Reserved.
 *
 * http://www.hunglead.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

namespace Plugin\HungleadRobotIn\ServiceProvider;

use Eccube\Application;
use Silex\Application as BaseApplication;
use Silex\ServiceProviderInterface;
use Symfony\Component\HttpFoundation\JsonResponse;


/**
 * Harc連携用のサービス提供クラス
 *  # ルーティングの追加
 *
 * @author hunglead.doishun
 */
class HarcServiceProvider implements ServiceProviderInterface
{

    public function register(BaseApplication $app)
    {
        // html/harc/get_orders.php
        $app->match('/harc/get_orders.php'           , '\\Plugin\\HungleadRobotIn\\Controller\\GetOrdersController::index')->bind('ri_orders');
//        $app->match('/test/get_orders_test.php'      , '\\Plugin\\HungleadRobotIn\\Controller\\GetOrdersController::test' )->bind('ri_orders_test');

        // html/harc/get_order.php
        $app->match('/harc/get_order.php'            , '\\Plugin\\HungleadRobotIn\\Controller\\GetOrderController::index')->bind('ri_order');
//        $app->match('/test/get_order_test.php'       , '\\Plugin\\HungleadRobotIn\\Controller\\GetOrderController::test' )->bind('ri_order_test');

        // html/harc/change_status.php
        $app->match('/harc/change_status.php'        , '\\Plugin\\HungleadRobotIn\\Controller\\ChangeStatusController::index')->bind('ri_change_status');
//        $app->match('/test/change_status_test.php'   , '\\Plugin\\HungleadRobotIn\\Controller\\ChangeStatusController::test' )->bind('ri_change_status_test');

        // html/harc/update_products.php
        $app->match('/harc/update_products.php'      , '\\Plugin\\HungleadRobotIn\\Controller\\UpdateProductsController::index')->bind('ri_update_products');
//        $app->match('/test/update_products_test.php' , '\\Plugin\\HungleadRobotIn\\Controller\\UpdateProductsController::test' )->bind('ri_update_products_test');
    }


    public function boot(BaseApplication $app)
    {
    }


    /**
     * Robot-inに結果を返す
     *  # json形式かつクッキーに値をセットする
     * 
     * @param  array  $result
     * @param  string $unique_key
     * @return json
     */
    public static function sendResponse($results, $unique_key=""){
        if(strlen($unique_key) > 0){
            setcookie('Robot-in', $unique_key);
        }
        
        return new JsonResponse($results);
    }


}
